kumoai.experimental
===================

Relational Foundation Model (RFM)
---------------------------------

.. currentmodule:: kumoai.experimental.rfm

.. autosummary::
   :nosignatures:
   :toctree: ../generated

   LocalTable
   LocalGraph
   KumoRFM

For detailed documentation and examples, see: :doc:`experimental_rfm`
